@@ -3,12 +3,14 @@
 {
     'name': 'Sale',
     'name_bg_BG': 'Продажби',
+    'name_ca_ES': 'Vendes',
     'name_de_DE': 'Verkauf',
+    'name_es_AR': 'Venta',
     'name_es_CO': 'Ventas',
-    'name_es_ES': 'Venta',
+    'name_es_ES': 'Ventas',
     'name_fr_FR': 'Vente',
     'name_nl_NL': 'Verkoop',
-    'version': '2.2.3',
+    'version': '2.4.1',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -20,11 +22,11 @@ With the possibilities:
     - to follow invoice and shipment states from the sale order.
     - to define invoice method:
         - Manual
-        - On Order Confirmed
+        - On Order Processed
         - On shipment Sent
     - to define shipment method:
         - Manual
-        - On Order Confirmed
+        - On Order Processed
         - On Invoice Paid
 ''',
     'description_bg_BG': ''' Задаване на поръчка за продажба.
@@ -41,6 +43,21 @@ With the possibilities:
         - Ръчно
         - При потвърждаване на поръчката
         - При плащане на фактурата
+''',
+   'description_ca_ES': '''- Defineix comandes de venda.
+- Afegeix informació de vendes als productes.
+- Defineix el preu de venda com el preu de la llista.
+
+Amb la possibilitat de:
+    - Seguir els estats de facturació i enviament des de la comanda de venda.
+    - Definir el mètode de facturació:
+        - Manual
+        - A la confirmació de la comanda
+        - A l'enviar-la
+    - Definir el mètode d'enviament:
+        - Manual
+        - A la confirmació de la comanda
+        - Al cobrar la factura
 ''',
     'description_de_DE': ''' - Dient der Erstellung von Verkaufsvorgängen (Entwurf, Angebot, Auftrag).
  - Fügt den Artikeln Einkaufsinformationen hinzu.
@@ -56,6 +73,21 @@ Ermöglicht:
         - Manuell
         - Nach Auftragsbestätigung
         - Nach Bezahlung
+''',
+    'description_es_AR': '''Define orden de venta.
+ - Añade a los productos información de ventas.
+ - Define el precio de venta como el precio de lista.
+
+ - Con la posibilidad de:
+    - seguir los estados de facturación y envio desde la orden de venta.
+    - definir el método de facturación:
+        - Manual
+        - A la confirmación de la orden
+        - Al enviarlo
+    - definir el método de envio:
+        - Manual
+        - Al confirmar la orden
+        - Al pagar la factura
 ''',
     'description_es_CO': ''' - Define la orden de Ventas.
  - Se añade al producto la información de ventas.
@@ -72,19 +104,19 @@ Ermöglicht:
         - Al Confirmar la Orden
         - Contra el Pago de la Factura
 ''',
-    'description_es_ES': '''Define orden de venta.
- - Añade a los productos información de ventas.
- - Define el precio de venta como el precio de lista.
+    'description_es_ES': '''- Define pedido de venta.
+- Añade información de venta a los productos.
+- Define el precio de venta como el precio de lista.
 
- - Con la posibilidad de:
-    - seguir los estados de facturación y envio desde la orden de venta.
-    - definir el método de facturación:
+Con la posibilidad de:
+    - Seguir los estados de facturación y envío desde el pedido de venta.
+    - Definir el método de facturación:
         - Manual
-        - A la confirmación de la orden
+        - A la confirmación del pedido
         - Al enviarlo
-    - definir el método de envio:
+    - Definir el método de envío:
         - Manual
-        - Al confirmar la orden
+        - Al confirmar el pedido
         - Al pagar la factura
 ''',
     'description_fr_FR': '''Défini l'ordre de vente.
@@ -101,7 +133,7 @@ Avec la possibilité:
         - Sur confirmation de la commande
         - Au paiement de la facture
 ''',
-	'description_nl_NL': '''Verkoopmodule.
+    'description_nl_NL': '''Verkoopmodule.
 Voegt verkoopinformatie toe aan producten.
 Zet de catalogusprijs als verkoopprijs.
 
@@ -123,7 +155,6 @@ Biedt mogelijkheden tot:
         'account',
         'product',
         'account_invoice',
-        'workflow',
         'res',
         'ir',
         'currency',
@@ -133,11 +164,15 @@ Biedt mogelijkheden tot:
         'sale.xml',
         'configuration.xml',
         'party.xml',
+        'stock.xml',
+        'product.xml',
     ],
     'translation': [
         'locale/bg_BG.po',
+        'locale/ca_ES.po',
         'locale/cs_CZ.po',
         'locale/de_DE.po',
+        'locale/es_AR.po',
         'locale/es_CO.po',
         'locale/es_ES.po',
         'locale/fr_FR.po',
